@@ -3,14 +3,14 @@ from functools import reduce
 
 __author__ = """Romain Picard"""
 __email__ = 'romain.picard@oakbits.com'
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 
 
 # bins is a tuple of (cut point, count)
 class Distogram(object):
     '''Compressed representation of the histogram of a distribution
     '''
-    __slots__ = 'bin_count', 'bins'
+    __slots__ = 'bin_count', 'bins', 'min', 'max'
 
     def __init__(self, bin_count=100):
         '''Creates a new Distogram object
@@ -23,6 +23,8 @@ class Distogram(object):
         '''
         self.bin_count = bin_count
         self.bins = []
+        self.min = None
+        self.max = None
 
 
 def _linspace(start, stop, num):
@@ -79,7 +81,6 @@ def update(h, value, count=1):
     bins = h.bins
     for index, bin in enumerate(bins):
         if bin[0] == value:
-            print("same: {}, {}".format(bin[0], value))
             bin = (bin[0], bin[1]+count)
             h.bins[index] = bin
             return h
@@ -87,6 +88,10 @@ def update(h, value, count=1):
     bins.append((value, count))
     bins = sorted(bins, key=lambda i: i[0])
     h.bins = bins
+    if h.min is None or h.min > value:
+        h.min = value
+    if h.max is None or h.max < value:
+        h.max = value
     return trim(h)
 
 
@@ -117,7 +122,14 @@ def count_at(h, value):
     Returns:
         An estimation of the real count, computed from the compressed
         representation of the distribution.
+
+    Raises:
+        ValueError if distribution contains less elements than the number of
+        bins in the Distogram object.
     '''
+    if len(h.bins) < h.bin_count:
+        raise ValueError("not enough elements in distribution")
+
     bins = h.bins
     i = -1
     while value > bins[i+1][0] and i < len(bins) - 1:
@@ -153,9 +165,9 @@ def bounds(h):
         h: A Distogram object.
 
     Returns:
-        An estimation of the minimum and maximum values of the distribution.
+        A tuple containing the minimum and maximum values of the distribution.
     '''
-    return (h.bins[0][0], h.bins[-1][0])
+    return (h.min, h.max)
 
 
 def mean(h):
@@ -208,10 +220,17 @@ def histogram(h, ucount=100):
 
     Returns:
         An estimation of the histogram of the distribution.
+
+    Raises:
+        ValueError if distribution contains less elements than the number of
+        bins in the Distogram object.
     '''
+    if len(h.bins) < h.bin_count:
+        raise ValueError("not enough elements in distribution")
+
     last = 0.0
     u = []
-    bounds = _linspace(h.bins[0][0], h.bins[-1][0], num=ucount+1)
+    bounds = _linspace(h.min, h.max, num=ucount+1)
     for e in bounds[1:-1]:
         new = count_at(h, e)
         u.append((e, new-last))
@@ -228,7 +247,14 @@ def quantile(h, value):
 
     Returns:
         An estimation of the quantile.
+
+    Raises:
+        ValueError if distribution contains less elements than the number of
+        bins in the Distogram object.
     '''
+    if len(h.bins) < h.bin_count:
+        raise ValueError("not enough elements in distribution")
+
     total_count = count(h)
     q_count = int(total_count * value)
     bins = h.bins
