@@ -1,3 +1,4 @@
+import pytest
 from pytest import approx
 import random
 import distogram
@@ -23,6 +24,17 @@ def test_count_at_normal():
     h = distogram.Distogram()
 
     for i in normal:
-        distogram.update(h, i)
+        h = distogram.update(h, i)
 
     assert distogram.count_at(h, 0) == approx(points/2, rel=0.025)
+
+
+def test_count_at_not_enough_elements():
+    h = distogram.Distogram()
+
+    h = distogram.update(h, 1)
+    h = distogram.update(h, 2)
+    h = distogram.update(h, 3)
+
+    with pytest.raises(ValueError):
+        h = distogram.count_at(h, 2.5)
